#
# spec file for package python-python-cjson
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-python-cjson
Version:        1.2.1
Release:        bp154.1.22
Summary:        C-accelerated JSON encoder/decoder for Python
License:        LGPL-2.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/AGProjects/python-cjson
Source:         https://files.pythonhosted.org/packages/source/p/python-cjson/python-cjson-%{version}.tar.gz
# https://github.com/AGProjects/python-cjson/issues/6
Patch0:         py3.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros

%python_subpackages

%description
JSON (JavaScript Object Notation) is a text-based data exchange
format.

The module is written in C and it is up to 250 times faster when compared to
the other Python JSON implementations which are written directly in Python.
This speed gain varies with the complexity of the data and the operation and is
the the range of 10-200 times for encoding operations and in the range of
100-250 times for decoding operations.

%prep
%setup -q -n python-cjson-%{version}
%if %{with python2}
cp cjson.c cjson%{python2_bin_suffix}.c
cp jsontest.py jsontest%{python2_bin_suffix}.py
%endif
%patch0 -p1
cp cjson.c cjson%{python3_bin_suffix}.c

cp jsontest.py jsontest%{python3_bin_suffix}.py
# Workaround dict order differences on Python 3.4
if [ %{python3_bin_suffix} = '3.4' ]; then
  sed -i 's/\(testWriteComplexArray\|testWriteSmallObject\)/_\1/' jsontest%{python3_bin_suffix}.py
fi

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%if %{with python2}
rm cjson.c
ln -s cjson%{python2_bin_suffix}.c cjson.c
%python2_build
%endif
rm cjson.c
ln -s cjson%{python3_bin_suffix}.c cjson.c
%python3_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python jsontest%{$python_bin_suffix}.py

%files %{python_files}
%doc ChangeLog README
%license LICENSE
%{python_sitearch}/*

%changelog
* Thu Apr 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Mon Jun  3 2019 Jan Engelhardt <jengelh@inai.de>
- Trim encyclopedic JSON report from description.
* Sat May 11 2019 John Vandenberg <jayvdb@gmail.com>
- Rename package from python-cjson to python-python-cjson
- Add Python 3 support using py3.patch
- Update to v1.2.1
  * Updated project homepage
- from v1.2.0
  * Implemented recursion limit check for encoding/decoding arrays and objects
  * Updated copyright years and stripped licensing info from source code
- from v1.1.0
  * Use repr instead of str when encoding floats to preserve full preicision
  * Fixed windows compilation problem introduced in 1.0.5
  * Fixed float write test to work with latest high precision float encoding
  * Fixed some list/dict decoding bugs. Use a state machine for decoding them.
  * Improved decoding speed by using PyString_GET_SIZE instead of strlen
  * Integrate modified 0001-fix-for-CVE-2010-1666 patch from Debian
* Sat Mar  7 2009 lars@linux-schulserver.de
- build for openSUSE
* Mon Oct 29 2007 James Oakley <jfunk@funktronics.ca> - 1.0.5-1
- Update to 1.0.5
  - Check if module initialization failed.
  - Removed useless checks on module initialization.
  - Added __version__ attribute to the cjson module.
  - Call Py_INCREF before calling PyModule_AddObject.
- Changes in version 1.0.4
  - Added licensing information.
  - Fixed issue with decrementing a string reference too early
    (Edouard Hinard <edouard.hinard@orange-ftgroup.com>).
  - Fixed 64-bit portability problems (based on a modified version of a
    patch by David Rushby <davidrushby@yahoo.com>).
  - Fixed issue with not returning NULL after setting the OverflowError
    when encoded strings would be too big.
  - Fixed 2 potential buffer overflow errors when encoding string/unicode
    (thanks to Ofer Faigon <ofer3@bitformation.com> for pointing them out).
  - About 10%% speed improvement when encoding/decoding string/unicode.
* Thu Jul 12 2007 James Oakley <jfunk@funktronics.ca> - 1.0.3x6-1
- Update to 1.0.3x6
  - Fixed segmentation fault
    Fixed a rare, but reproducible segmentation fault when decoding specially
    crafted unicode strings. Bug reported by: Liu Cougar - China
* Sat Mar  3 2007 James Oakley <jfunk@funktronics.ca> - 1.0.3-1
- Initial release
